==> haskell-hspec-discover-2.4.4-3-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-hspec-discover.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hspec-discover
version: 2.4.4
id: hspec-discover-2.4.4-IItbyzxoQ94KZ3DWPccN8F
key: hspec-discover-2.4.4-IItbyzxoQ94KZ3DWPccN8F
license: MIT
copyright: (c) 2012-2017 Simon Hengel
maintainer: Simon Hengel <sol@typeful.net>
stability: experimental
homepage: http://hspec.github.io/
synopsis: Automatically discover and run Hspec tests
description:
    Automatically discover and run Hspec tests
    .
    <http://hspec.github.io/hspec-discover.html>
category: Testing
author: Simon Hengel <sol@typeful.net>
exposed: False
indefinite: False
exposed-modules:
    Test.Hspec.Discover.Config Test.Hspec.Discover.Run
hidden-modules: Paths_hspec_discover
abi: ea3e06076cfd036d99b4876dbf57f7b1
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/hspec-discover-2.4.4
library-dirs: /usr/lib/ghc-8.2.1/site-local/hspec-discover-2.4.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.1/hspec-discover-2.4.4
hs-libraries: HShspec-discover-2.4.4-IItbyzxoQ94KZ3DWPccN8F
depends:
    base-4.10.0.0 filepath-1.4.1.2 directory-1.3.0.2
abi-depends: base-4.10.0.0=32d562aa6d04d35ac79a0f49c17325ff
             filepath-1.4.1.2=30ad74f2069d36b2d0af3972630d4ac4
             directory-1.3.0.2=f0be8e5bd351f97ab9c9e693d2eba4ad
haddock-interfaces: /usr/share/doc/haskell-hspec-discover/html/hspec-discover.haddock
haddock-html: /usr/share/doc/haskell-hspec-discover/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hspec-discover-2.4.4-4-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-hspec-discover.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hspec-discover
version: 2.4.4
id: hspec-discover-2.4.4-7lu7rN66esZ31cqN0Q1d1c
key: hspec-discover-2.4.4-7lu7rN66esZ31cqN0Q1d1c
license: MIT
copyright: (c) 2012-2017 Simon Hengel
maintainer: Simon Hengel <sol@typeful.net>
stability: experimental
homepage: http://hspec.github.io/
synopsis: Automatically discover and run Hspec tests
description:
    Automatically discover and run Hspec tests
    .
    <http://hspec.github.io/hspec-discover.html>
category: Testing
author: Simon Hengel <sol@typeful.net>
exposed: False
indefinite: False
exposed-modules:
    Test.Hspec.Discover.Config Test.Hspec.Discover.Run
hidden-modules: Paths_hspec_discover
abi: 93c4d8ce8247a6f04cd26ec90f56f6e5
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/hspec-discover-2.4.4
library-dirs: /usr/lib/ghc-8.2.2/site-local/hspec-discover-2.4.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/hspec-discover-2.4.4
hs-libraries: HShspec-discover-2.4.4-7lu7rN66esZ31cqN0Q1d1c
depends:
    base-4.10.1.0 filepath-1.4.1.2 directory-1.3.0.2
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             filepath-1.4.1.2=a40cd48e5480796e558f3c29652ee19a
             directory-1.3.0.2=7b913664ccd770192b307d7c4c6817cc
haddock-interfaces: /usr/share/doc/haskell-hspec-discover/html/hspec-discover.haddock
haddock-html: /usr/share/doc/haskell-hspec-discover/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
